/**
This file is part of a jTEM project.
All jTEM projects are licensed under the FreeBSD license 
or 2-clause BSD license (see http://www.opensource.org/licenses/bsd-license.php). 

Copyright (c) 2006-2009, Technische Universität Berlin, jTEM
All rights reserved.

Redistribution and use in source and binary forms, with or without modification, 
are permitted provided that the following conditions are met:

-	Redistributions of source code must retain the above copyright notice, 
	this list of conditions and the following disclaimer.

-	Redistributions in binary form must reproduce the above copyright notice, 
	this list of conditions and the following disclaimer in the documentation 
	and/or other materials provided with the distribution.
 
THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS 
BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, 
OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT 
OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, 
STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING 
IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY 
OF SUCH DAMAGE.
**/

package de.jtem.modelling;


import java.util.Set;

import javax.swing.event.ChangeListener;

/**
 * Interface for classes that provide facilities for inspecting the bean
 * properties of arbitrary objects. The contract concerning ChangeListeners is:
 * Whenever a property of an inspected object is changed, a ChangeEvent with
 * the inspected object as its source is distributed.
 * 
 * @author Ulrich
 *
 */
public interface Inspector {
	
	/**
	 * Makes the bean properties of an object available for inspection
	 * 
	 * @param o The object to inspect.
	 * 
	 * @param excludedProperties Contains the names of the properties that
	 * should not be inspected.
	 */
	void inspect(Object o, Set<String>excludedProperties);
	
	/**
	 * 
	 * @param l The listener to be added
	 */
	void addChangeListener(ChangeListener l);
	
	/**
	 * The listener to be removed
	 * @param l
	 */
	void removeChangeListener(ChangeListener l);
	
	/**
	 * Returns the currently inspected object
	 * @return The inspected object
	 */
	Object getObject();
}
