/**
This file is part of a jTEM project.
All jTEM projects are licensed under the FreeBSD license 
or 2-clause BSD license (see http://www.opensource.org/licenses/bsd-license.php). 

Copyright (c) 2006-2009, Technische Universität Berlin, jTEM
All rights reserved.

Redistribution and use in source and binary forms, with or without modification, 
are permitted provided that the following conditions are met:

-	Redistributions of source code must retain the above copyright notice, 
	this list of conditions and the following disclaimer.

-	Redistributions in binary form must reproduce the above copyright notice, 
	this list of conditions and the following disclaimer in the documentation 
	and/or other materials provided with the distribution.
 
THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS 
BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, 
OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT 
OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, 
STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING 
IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY 
OF SUCH DAMAGE.
**/

package de.jtem.modelling;

import java.io.File;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.io.Reader;
import java.util.HashMap;

import javax.swing.JFileChooser;
import javax.swing.filechooser.FileFilter;
import javax.swing.filechooser.FileSystemView;

import com.thoughtworks.xstream.XStream;
import com.thoughtworks.xstream.converters.reflection.PureJavaReflectionProvider;


public class ModellerIO {

	public static void write(File file, Modeller modeller) throws IOException {
		XStream xstream = new XStream(new PureJavaReflectionProvider());
		//XStream xstream = new XStream(new BeanProvider());
		//xstream.registerConverter(new SceneComponentConverter(xstream.getClassMapper()));
		FileWriter fileWriter = new FileWriter(file);
		System.out.println(modeller.toolToTemplate);
		xstream.toXML(modeller.toolToTemplate, fileWriter);
		fileWriter.close();
	}

	public static void load(File xmlFile, Modeller modeller) throws IOException {
		XStream xstream = new XStream(new PureJavaReflectionProvider());
		//xstream.registerConverter(new SceneComponentConverter(xstream.getClassMapper()));
		Reader xml = new FileReader(xmlFile);
		HashMap<ModellingTool, String> map = (HashMap<ModellingTool, String>) xstream
				.fromXML(xml);
		for (ModellingTool t : map.keySet()) {
			modeller.addTool(t, map.get(t));
		}
	}

	static File lastDir;

	// static JFileChooser createFileChooser(final String ext, final String
	// description) {
	// FileFilter ff = new FileFilter(){
	// public boolean accept(File arg0) {
	// if (arg0.isDirectory()) return true;
	// if(arg0.getName().endsWith("."+ext))
	// return true;
	// return false;
	// }
	//
	// public String getDescription() {
	// return description;
	// }
	// };
	// return createFileChooser(ff);
	// }
	
	public static JFileChooser createFileChooser(FileFilter ff) {
		FileSystemView view = FileSystemView.getFileSystemView();
		JFileChooser chooser = new JFileChooser((lastDir == null || !lastDir.exists()) ? view
				.getHomeDirectory() : lastDir, view);
		if (ff != null) chooser.addChoosableFileFilter(ff);
		return chooser;
	}

}
