/**
This file is part of a jTEM project.
All jTEM projects are licensed under the FreeBSD license 
or 2-clause BSD license (see http://www.opensource.org/licenses/bsd-license.php). 

Copyright (c) 2006-2009, Technische Universität Berlin, jTEM
All rights reserved.

Redistribution and use in source and binary forms, with or without modification, 
are permitted provided that the following conditions are met:

-	Redistributions of source code must retain the above copyright notice, 
	this list of conditions and the following disclaimer.

-	Redistributions in binary form must reproduce the above copyright notice, 
	this list of conditions and the following disclaimer in the documentation 
	and/or other materials provided with the distribution.
 
THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS 
BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, 
OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT 
OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, 
STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING 
IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY 
OF SUCH DAMAGE.
**/

package de.jtem.modelling;


/**
 * Interface for classes that provide facilities for displaying scenes and
 * provide access to some global menu to perform actions. It is understood
 * that the scene graph related methods are performed after casting the scene
 * components to the classes appropriate for the given context.
 * 
 * @author Ulrich Pinkall
 */
public interface ModellingViewer {
	
	/**
	 * Redisplays the entire scene.
	 */
	void render();
	
	/**
	 * Adds the child to the parent in the scene graph.
	 *  
	 * @param child The child scene.
	 * @param parent The parent scene.
	 */
	void addChildSceneToParentScene(Object child, Object parent);
	
	/**
	 * Removes the child from the parent in the scene graph.
	 *  
	 * @param child The child scene.
	 * @param parent The parent scene.
	 */
	void removeChildSceneFromParentScene(Object child, Object parent);
	
	/**
	 * Adds a scene to the global view.
	 * 
	 * @param scene The scene to be added.
	 */
	
	void removeScene(Object scene);
	/**
	 * removes a scene to the global view.
	 * 
	 * @param scene The scene to be removed.
	 */
	void addScene(Object scene);
	
	/**
	 * Returns the position (in world coordinates of the appropriate space)
	 * where the last event (e.g. mouse click) happened that led to the user
	 * being presented with the global action menu.
	 * 
	 * @return The position.
	 */
	double[] getLastMenuLocation();
}
